AddressHasher

Struct AddressHasher 

pub struct AddressHasher { /* private fields */ }
Available on crate feature rand and neither target_os=solana nor target_arch=bpf only.
A faster, but less collision resistant hasher for addresses.

Specialized hasher that uses a random 8 bytes subslice of the address as the hash value. Should not be used when collisions might be used to mount DOS attacks.

Using this results in about 4x faster lookups in a typical hashmap.